@@ -9,6 +9,7 @@ from __future__ import with_statement
 
 import tests
 
+import time
 
 from zim.async import *
 from zim.fs import File
@@ -31,10 +32,11 @@ class TestAsync(tests.TestCase):
 
 			self.assertEqual(value, 'foo bar')
 
+	@tests.slowTest
 	def testFS(self):
 		'''Test async FS operations'''
 
-		self.path = tests.create_tmp_dir('async_testFS')+'/file.txt'
+		self.path = self.create_tmp_dir('testFS')+'/file.txt'
 
 		file = File(self.path)
 
@@ -45,3 +47,31 @@ class TestAsync(tests.TestCase):
 		op2.wait()
 
 		self.assertEqual(file.read(), 'foo bar 2\n')
+
+
+class Counter(object):
+
+	def __init__(self):
+		self.i = 0
+
+	def count(self):
+		self.i += 1
+
+
+@tests.slowTest
+class TestDelayedCallback(tests.TestCase):
+
+	def runTest(self):
+		counter = Counter()
+
+		callback = DelayedCallback(500, lambda o: counter.count())
+		for i in range(3):
+			callback('foo')
+
+		for i in range(10):
+			time.sleep(1)
+			tests.gtk_process_events()
+			if callback.timer_id is None:
+				break
+
+		self.assertEqual(counter.i, 1)
