@@ -1,8 +1,11 @@
+# -*- coding: utf-8 -*-
+
+# Copyright 2009 Jaap Karssenberg <jaap.karssenberg@gmail.com>
 
 from __future__ import with_statement
 
-from tests import TestCase, get_test_notebook, create_tmp_dir, MockObject
-from tests.gtk import TestDialogContext
+import tests
+
 
 from zim.errors import Error
 from zim.notebook import get_notebook_list, Path, NotebookInfo
@@ -14,14 +17,15 @@ import zim.gui
 from zim.gui.clipboard import *
 
 
-class TestClipboard(TestCase):
+@tests.slowTest
+class TestClipboard(tests.TestCase):
 
 	def runTest(self):
 		'''Test clipboard interaction'''
+		path = self.get_tmp_name()
+		notebook = tests.new_notebook(fakedir=path)
+
 		clipboard = Clipboard()
-		notebook = get_test_notebook()
-		tmp_dir = create_tmp_dir('gui_Clipboard')
-		notebook.get_store(Path(':')).dir = Dir(tmp_dir) # fake source dir
 
 		# tree roundtrip
 		for pagename in ('Test:wiki', 'roundtrip'):
@@ -40,7 +44,7 @@ class TestClipboard(TestCase):
 
 		wanted = 'some **bold** text\n'
 		text = clipboard.wait_for_text()
-		self.assertEqualDiff(text, wanted)
+		self.assertEqual(text, wanted)
 
 		wanted = '''\
 <html>
@@ -58,7 +62,7 @@ some <strong>bold</strong> text<br>
 </html>
 '''
 		selection = clipboard.wait_for_contents('text/html')
-		self.assertEqualDiff(selection.data, wanted)
+		self.assertEqual(selection.data, wanted)
 
 		wanted = '''\
 Version:1.0\r
@@ -76,7 +80,7 @@ some <strong>bold</strong> text<br>
 </p>
 <!--EndFragment--></BODY></HTML>'''
 		selection = clipboard.wait_for_contents('HTML Format')
-		self.assertEqualDiff(selection.data, wanted)
+		self.assertEqual(selection.data, wanted)
 
 
 		# pagelink -> ..
@@ -90,8 +94,8 @@ some <strong>bold</strong> text<br>
 		self.assertEqual(selection.data, 'Unnamed Notebook?Test:wiki\r\n')
 
 		wanted = '''\
-<?xml version=\'1.0\' encoding=\'utf-8\'?>\n<zim-tree><link href="Test:wiki">Test:wiki</link></zim-tree>'''
-		newtree = clipboard.request_parsetree(None, notebook, page, block=True)
+<?xml version=\'1.0\' encoding=\'utf-8\'?>\n<zim-tree><link href="+wiki">+wiki</link></zim-tree>'''
+		newtree = clipboard.request_parsetree(None, notebook, Path('Test'), block=True)
 		self.assertEqual(newtree.tostring(), wanted)
 
 		text = clipboard.wait_for_text()
@@ -119,8 +123,8 @@ some <strong>bold</strong> text<br>
 		file = File('/foo/bar/baz.txt')
 		clipboard.set_with_data(targets, my_get_data, my_clear_data, file)
 		tree = clipboard.request_parsetree(None, notebook, page, block=True)
-		img = tree.find('link')
-		rel_path = img.get('href')
+		link = tree.find('link')
+		rel_path = link.get('href')
 		self.assertEqual(notebook.resolve_file(rel_path, page), file)
 
 		file = File('./data/zim.png')
@@ -157,12 +161,12 @@ some <strong>bold</strong> text<br>
 		self.assertEqual(notebook.resolve_file(rel_path, page), file_obj)
 
 
-class TestDialogs(TestCase):
-
-	slowTest = True
+@tests.slowTest
+class TestDialogs(tests.TestCase):
 
 	def setUp(self):
-		self.ui = MockUI('Test:foo:bar')
+		path = self.create_tmp_dir()
+		self.ui = MockUI('Test:foo:bar', fakedir=path)
 
 	def testOpenPageDialog(self):
 		'''Test OpenPageDialog dialog (Jump To...)'''
@@ -179,6 +183,9 @@ class TestDialogs(TestCase):
 
 	def testNewPageDialog(self):
 		'''Test NewPageDialog'''
+		self.ui.mainwindow = tests.MockObject()
+		self.ui.mainwindow.pageview = tests.MockObject()
+
 		for name, path in (
 			(':new', ':new'),
 			('foo:new', ':Test:foo:new'),
@@ -217,7 +224,7 @@ class TestDialogs(TestCase):
 
 	def testSaveCopyDialog(self):
 		'''Test SaveCopyDialog'''
-		tmp_dir = create_tmp_dir('gui_SaveCopyDialog')
+		tmp_dir = self.create_tmp_dir('testSaveCopyDialog')
 		file = File((tmp_dir, 'save_copy.txt'))
 		self.assertFalse(file.exists())
 		dialog = zim.gui.SaveCopyDialog(self.ui)
@@ -227,11 +234,10 @@ class TestDialogs(TestCase):
 
 	def testImportPageDialog(self):
 		'''Test ImportPageDialog'''
-		tmp_dir = create_tmp_dir('gui_ImportPageDialog')
+		tmp_dir = self.create_tmp_dir('testImportPageDialog')
 		file = File((tmp_dir, 'import_page.txt'))
 		file.write('test 123\n')
 		self.assertTrue(file.exists())
-		self.ui = MockUI()
 		dialog = zim.gui.ImportPageDialog(self.ui)
 		dialog.set_file(file)
 		#~ dialog.assert_response_ok()
@@ -299,15 +305,13 @@ class TestDialogs(TestCase):
 
 	def testAttachFileDialog(self):
 		'''Test AttachFileDialog'''
-		tmp_dir = create_tmp_dir('gui_AttachFileDialog')
+		tmp_dir = self.create_tmp_dir('testAttachFileDialog')
 		file = File((tmp_dir, 'file_to_be_attached'))
 		file.write('Test 1 2 3\n')
 		newfile = File((tmp_dir, 'attachments', 'Test', 'foo', 'file_to_be_attached'))
 		self.assertTrue(file.exists())
 		self.assertFalse(newfile.exists())
 
-		store = self.ui.notebook.get_store(Path(':'))
-		store.dir = Dir((tmp_dir, 'attachments')) # Fake dir based notebook
 		dialog = zim.gui.AttachFileDialog(self.ui, path=Path('Test:foo'))
 		dialog.set_file(file)
 		#~ dialog.assert_response_ok()
@@ -315,20 +319,19 @@ class TestDialogs(TestCase):
 		#~ self.assertTrue(file.exists()) # No move or delete happened
 		#~ self.assertTrue(newfile.exists())
 		#~ self.assertTrue(newfile.compare(file))
-		#~ del store.dir
 
 	def testSearchDialog(self):
 		'''Test SearchDialog'''
 		from zim.gui.searchdialog import SearchDialog
-		self.ui.notebook = get_test_notebook()
+		self.ui.notebook = tests.new_notebook()
 		dialog = SearchDialog(self.ui)
 		dialog.query_entry.set_text('Foo')
 		dialog.query_entry.activate()
 		model = dialog.results_treeview.get_model()
 		self.assertTrue(len(model) > 3)
 
-		self.ui.mainwindow = MockObject()
-		self.ui.mainwindow.pageview = MockObject()
+		self.ui.mainwindow = tests.MockObject()
+		self.ui.mainwindow.pageview = tests.MockObject()
 		col = dialog.results_treeview.get_column(0)
 		dialog.results_treeview.row_activated((0,), col)
 
@@ -396,16 +399,18 @@ class TestDialogs(TestCase):
 
 		config1 = {
 			'name': 'Notebook Foo',
+			'interwiki': '',
 			'home': 'Home',
 			'icon': './icon.png',
-			'document_root': '/foo',
+			'document_root': File('/foo').path, # win32 save test
 			'shared': False,
 		}
 		config2 = {
 			'name': 'Notebook Bar',
+			'interwiki': 'FooBar',
 			'home': 'HomeSweetHome',
 			'icon': './picture.png',
-			'document_root': '/bar',
+			'document_root': File('/bar').path, # win32 save test
 			'shared': True,
 		}
 		notebook.save_properties(**config1)
@@ -483,21 +488,217 @@ class TestDialogs(TestCase):
 	# Test for NotebookDialog is in separate class below
 
 
-class TestGtkInterface(TestCase):
 
-	slowTest = True
+class FilterNoSuchImageWarning(tests.LoggingFilter):
 
-	def runTest(self):
+	logger = 'zim.gui.pageview'
+	message = 'No such image:'
+
+
+@tests.slowTest
+class TestGtkInterface(tests.TestCase):
+
+	def setUp(self):
+		# start filtering
+		filter = FilterNoSuchImageWarning()
+		filter.wrap_test(self)
+
+		# flush preferences
+		preferences = config_file('preferences.conf')
+		preferences.file.remove()
+
+		# create interface object with new notebook
+		dirpath = self.get_tmp_name()
+		notebook = tests.new_notebook(fakedir=dirpath)
+		path = Path('Test:foo:bar')
+		self.ui = zim.gui.GtkInterface(notebook=notebook, page=path)
+
+		# finalize plugins
+		for plugin in self.ui.plugins:
+			plugin.finalize_ui(self.ui)
+
+	def tearDown(self):
+		self.ui.close()
+
+	def testInitialization(self):
+		'''Test Gtk interface initialization'''
+
+		# start without notebook should not complain
 		ui = zim.gui.GtkInterface()
 
+		# now take ui with notebook
+		ui = self.ui
+
+		# test read only (starts readonly because notebook has no dir or file)
+		self.assertTrue(ui.readonly)
+		ui.set_readonly(False)
+		self.assertFalse(ui.readonly)
+		ui.set_readonly(True)
+		self.assertTrue(ui.readonly)
+
+		# TODO more tests for readonly pages etc.
+
 		# test populating menus
 		menu = gtk.Menu()
 		ui.populate_popup('page_popup', menu)
 		items = menu.get_children()
-		self.assertTrue(len(items) > 3)
+		self.assertGreater(len(items), 3)
+
+		# remove plugins
+		self.assertGreater(len(ui.plugins), 3) # default plugins
+		plugins = [p.plugin_key for p in ui.plugins]
+		for name in plugins:
+			ui.unload_plugin(name)
+		self.assertEqual(len(ui.plugins), 0)
+
+		# and add them again
+		for name in plugins:
+			ui.load_plugin(name)
+		self.assertGreater(len(ui.plugins), 3)
+
+		# check registering an URL handler
+		func = tests.Counter(True)
+		ui.register_url_handler('foo', func)
+		ui.open_url('foo://bar')
+		self.assertTrue(func.count == 1)
+		ui.unregister_url_handler(func)
+
+	def testMainWindow(self):
+		'''Test main window'''
+		path = Path('Test:foo:bar')
+		window = self.ui.mainwindow
+		#~ print 'UISTATE INIT:', window.uistate
+
+		self.assertTrue(window.uistate['show_menubar'])
+		window.toggle_menubar()
+		self.assertFalse(window.uistate['show_menubar'])
+		window.toggle_menubar()
+		self.assertTrue(window.uistate['show_menubar'])
+
+		self.assertTrue(window.uistate['show_toolbar'])
+		window.toggle_toolbar()
+		self.assertFalse(window.uistate['show_toolbar'])
+		window.toggle_toolbar()
+		self.assertTrue(window.uistate['show_toolbar'])
+
+		self.assertTrue(window.uistate['show_statusbar'])
+		window.toggle_statusbar()
+		self.assertFalse(window.uistate['show_statusbar'])
+		window.toggle_statusbar()
+		self.assertTrue(window.uistate['show_statusbar'])
+
+		self.assertTrue(window.uistate['show_sidepane'])
+		window.toggle_sidepane()
+		self.assertFalse(window.uistate['show_sidepane'])
+		window.toggle_sidepane()
+		self.assertTrue(window.uistate['show_sidepane'])
+
+		# note: focus starts at sidepane due to toggle_sidepane above
+		self.assertEqual(window.get_focus(), window.pageindex.treeview)
+		self.assertEqual(window.get_selected_path(), path)
+		window.toggle_focus_sidepane()
+		self.assertEqual(window.get_focus(), window.pageview.view)
+		self.assertEqual(window.get_selected_path(), path)
+		window.toggle_focus_sidepane()
+		self.assertEqual(window.get_focus(), window.pageindex.treeview)
+		# TODO also check this with "show_sidepane" off
+
+		self.assertEqual(window.uistate['pathbar_type'], zim.gui.PATHBAR_RECENT)
+		for style in (
+			zim.gui.PATHBAR_NONE,
+			zim.gui.PATHBAR_HISTORY,
+			zim.gui.PATHBAR_PATH,
+			zim.gui.PATHBAR_RECENT,
+		):
+			window.set_pathbar(style)
+			self.assertEqual(window.uistate['pathbar_type'], style)
+			# TODO specific test for pathbar to exercize history, add / move / remove pages etc.
+
+		# note: no default style here - system default unknown
+		for style in (
+			zim.gui.TOOLBAR_ICONS_AND_TEXT,
+			zim.gui.TOOLBAR_ICONS_ONLY,
+			zim.gui.TOOLBAR_TEXT_ONLY,
+		):
+			window.set_toolbar_style(style)
+			self.assertEqual(window.uistate['toolbar_style'], style)
+
+		# note: no default style here - system default unknown
+		for size in (
+			zim.gui.TOOLBAR_ICONS_LARGE,
+			zim.gui.TOOLBAR_ICONS_SMALL,
+			zim.gui.TOOLBAR_ICONS_TINY,
+		):
+			window.set_toolbar_size(size)
+			self.assertEqual(window.uistate['toolbar_size'], size)
+
+		# FIXME: test fails because "readonly" not active because notebook was already readonly, so action never activatable
+		#~ self.assertTrue(ui.readonly)
+		#~ self.assertTrue(window.uistate['readonly'])
+		#~ window.toggle_readonly()
+		#~ self.assertFalse(ui.readonly)
+		#~ self.assertFalse(window.uistate['readonly'])
+		#~ window.toggle_readonly()
+		#~ self.assertTrue(ui.readonly)
+		#~ self.assertTrue(window.uistate['readonly'])
+
+	def testNavigation(self):
+		'''Test navigating the notebook with gtk interface'''
+
+		# build up some history
+		history = (
+			Path('Test:foo:bar'),
+			Path('Test:'),
+			Path('Test:foo:'),
+			Path('Test:foo:bar'),
+		)
+		for path in history:
+			self.ui.open_page(path)
+			self.assertEqual(self.ui.page, path)
+
+		# check forward & backward
+		for path in reversed(history[:-1]):
+			self.assertTrue(self.ui.open_page_back())
+			self.assertEqual(self.ui.page, path)
+		self.assertFalse(self.ui.open_page_back())
+
+		for path in history[1:]:
+			self.assertTrue(self.ui.open_page_forward())
+			self.assertEqual(self.ui.page, path)
+		self.assertFalse(self.ui.open_page_forward())
+
+		# check upward and downward
+		for path in (Path('Test:foo:'), Path('Test:')):
+			self.assertTrue(self.ui.open_page_parent())
+			self.assertEqual(self.ui.page, path)
+		self.assertFalse(self.ui.open_page_parent())
+
+		for path in (Path('Test:foo:'), Path('Test:foo:bar')):
+			self.assertTrue(self.ui.open_page_child())
+			self.assertEqual(self.ui.page, path)
+		self.assertFalse(self.ui.open_page_child())
+
+		# previous and next
+		self.assertTrue(self.ui.open_page_previous())
+		self.assertTrue(self.ui.open_page_next())
+		self.assertEqual(self.ui.page, Path('Test:foo:bar'))
+
+	def testSave(self):
+		'''Test saving a page from the interface'''
+		self.ui.set_readonly(False)
+		self.ui.open_page(Path('Non-exsiting:page'))
+		self.assertFalse(self.ui.page.exists())
+		self.assertTrue(self.ui.page.get_parsetree() is None)
+		self.assertTrue(self.ui.mainwindow.pageview._showing_template) # check HACK
+		self.ui.save_page()
+		self.assertFalse(self.ui.page.get_parsetree() is None)
+
+	# TODO notebook manipulation (new (sub)page, move, rename, delete ..)
+	# merge with tests for dialogs (?)
 
 
-class TestNotebookDialog(TestCase):
+@tests.slowTest
+class TestNotebookDialog(tests.TestCase):
 
 	def setUp(self):
 		list = config_file('notebooks.list')
@@ -509,7 +710,7 @@ class TestNotebookDialog(TestCase):
 		from zim.gui.notebookdialog import prompt_notebook, \
 			AddNotebookDialog, NotebookDialog
 
-		tmpdir = create_tmp_dir('gui_TestNotebookDialog')
+		tmpdir = self.create_tmp_dir()
 		dir1 = Dir(tmpdir + '/mynotebook1')
 		dir2 = Dir(tmpdir + '/mynotebook2')
 
@@ -520,7 +721,7 @@ class TestNotebookDialog(TestCase):
 			dialog.form['folder'] = dir1.path
 			dialog.assert_response_ok()
 
-		with TestDialogContext(doAddNotebook):
+		with tests.DialogContext(doAddNotebook):
 			self.assertEqual(prompt_notebook(), dir1.uri)
 
 		# Second time we get the list
@@ -530,7 +731,7 @@ class TestNotebookDialog(TestCase):
 			selection.select_path((0,)) # select first and only notebook
 			dialog.assert_response_ok()
 
-		with TestDialogContext(testNotebookDialog):
+		with tests.DialogContext(testNotebookDialog):
 			self.assertEqual(prompt_notebook(), dir1.uri)
 
 		# Third time we add a notebook and set the default
@@ -543,7 +744,7 @@ class TestNotebookDialog(TestCase):
 		def testAddNotebook(dialog):
 			self.assertTrue(isinstance(dialog, NotebookDialog))
 
-			with TestDialogContext(doAddNotebook):
+			with tests.DialogContext(doAddNotebook):
 				dialog.do_add_notebook()
 
 			dialog.combobox.set_active(0)
@@ -552,7 +753,7 @@ class TestNotebookDialog(TestCase):
 			selection.select_path((1,)) # select newly added notebook
 			dialog.assert_response_ok()
 
-		with TestDialogContext(testAddNotebook):
+		with tests.DialogContext(testAddNotebook):
 			self.assertEqual(prompt_notebook(), dir2.uri)
 
 		# Check the notebook exists and the notebook list looks like it should
@@ -574,7 +775,7 @@ class TestNotebookDialog(TestCase):
 			selection.select_path((1,)) # select newly added notebook
 			dialog.assert_response_ok()
 
-		with TestDialogContext(unsetDefault):
+		with tests.DialogContext(unsetDefault):
 			self.assertEqual(prompt_notebook(), dir2.uri)
 
 		list = get_notebook_list()
@@ -582,12 +783,12 @@ class TestNotebookDialog(TestCase):
 		self.assertTrue(list.default is None)
 
 
-class MockUI(MockObject):
+class MockUI(tests.MockObject):
 
-	tmp_dir = create_tmp_dir('gui_MockUI')
+	def __init__(self, page=None, fakedir=None):
+		tests.MockObject.__init__(self)
 
-	def __init__(self, page=None):
-		MockObject.__init__(self)
+		self.tmp_dir = self.create_tmp_dir()
 
 		if page and not isinstance(page, Path):
 			self.page = Path(page)
@@ -595,7 +796,4 @@ class MockUI(MockObject):
 			self.page = page
 
 		self.mainwindow = None
-		self.notebook = get_test_notebook()
-		self.notebook.dir = Dir(self.tmp_dir) # fake source dir
-		self.notebook.get_store(Path(':')).dir = self.notebook.dir
-
+		self.notebook = tests.new_notebook(fakedir=fakedir)
