@@ -1,11 +1,16 @@
+# -*- coding: utf-8 -*-
+
+# Copyright 2011 Jaap Karssenberg <jaap.karssenberg@gmail.com>
+
+import tests
 
-from tests import TestCase, create_tmp_dir, get_test_notebook
 
 from zim.fs import File, Dir
 from zim.notebook import Path
 from zim.gui.widgets import *
 
-class TestInputEntry(TestCase):
+
+class TestInputEntry(tests.TestCase):
 
 	def runTest(self):
 		'''Test InputEntry widget'''
@@ -45,24 +50,22 @@ class TestInputEntry(TestCase):
 		self.assertFalse(entry.get_input_valid())
 
 
-class TestFileEntry(TestCase):
+class TestFileEntry(tests.TestCase):
 
 	def setUp(self):
+		path = self.get_tmp_name()
+		self.notebook = tests.new_notebook(fakedir=path)
+
 		self.entry = FileEntry()
-		self.notebook = get_test_notebook()
-		self.notebook.index.update()
 
 	def runTest(self):
 		'''Test FileEntry widget'''
-		entry = self.entry
-		home = Dir('~')
-
-		dir = Dir(create_tmp_dir('widgets_' + entry.__class__.__name__))
 		path = Path('Foo:Bar')
-		self.notebook.dir = dir
-		self.notebook.get_store(path).dir = dir
+		entry = self.entry
 		entry.set_use_relative_paths(self.notebook, path)
 
+		home = Dir('~')
+		dir = self.notebook.dir
 		for file, text in (
 			(home.file('zim-test.txt'), '~/zim-test.txt'),
 			(dir.file('Foo/Bar/test.txt'), './test.txt'),
@@ -92,7 +95,7 @@ class TestFileEntry(TestCase):
 		for file, text in (
 			(home.file('zim-test.txt'), '~/zim-test.txt'),
 			(dir.file('Foo/Bar/test.txt'), './Foo/Bar/test.txt'),
-			(File('/test.txt'), 'file:///test.txt'),
+			(File('/test.txt'), File('/test.txt').uri), # win32 save
 			(doc_root.file('test.txt'), '/test.txt'),
 		):
 			entry.set_file(file)
@@ -104,27 +107,28 @@ class TestFileEntry(TestCase):
 		for file, text in (
 			(home.file('zim-test.txt'), '~/zim-test.txt'),
 			#~ (dir.file('Foo/Bar/test.txt'), './test.txt'),
-			(File('/test.txt'), '/test.txt'),
+			(File('/test.txt'), File('/test.txt').path), # win32 save
 		):
 			entry.set_file(file)
 			self.assertEqual(entry.get_text(), text)
 			self.assertEqual(entry.get_file(), file)
 
 
-class TestPageEntry(TestCase):
+class TestPageEntry(tests.TestCase):
 
 	entryklass = PageEntry
 
 	def setUp(self):
-		self.notebook = get_test_notebook()
+		path = self.get_tmp_name()
+		self.notebook = tests.new_notebook(fakedir=path)
+
 		self.reference = Path('Test:foo')
 		self.entry = self.entryklass(self.notebook, self.reference)
 
 	def runTest(self):
 		'''Test PageEntry widget'''
-		notebook = self.notebook
-		reference = self.reference
 		entry = self.entry
+		reference = self.reference
 
 		entry.set_path(Path('Test'))
 		self.assertEqual(entry.get_text(), ':Test')
@@ -162,6 +166,28 @@ class TestPageEntry(TestCase):
 		self.assertEqual(get_completions(entry), ['Test:foo', 'Test:Foo Bar', 'Test:tags', 'Test:wiki'])
 
 
+class TestNamespaceEntry(TestPageEntry):
+
+	entryklass = NamespaceEntry
+
+	def runTest(self):
+		'''Test NamespaceEntry widget'''
+		entry = self.entry
+		entry.set_text('')
+
+		entry.do_focus_in_event(gtk.gdk.Event(gtk.gdk.FOCUS_CHANGE))
+		self.assertTrue(entry.get_input_valid())
+		self.assertEqual(entry.get_text(), '') # No '<Top>' or something !
+		self.assertEqual(entry.get_path(), Path(':'))
+
+		entry.do_focus_out_event(gtk.gdk.Event(gtk.gdk.FOCUS_CHANGE))
+		self.assertTrue(entry.get_input_valid())
+		self.assertEqual(entry.get_text(), '') # No '<Top>' or something !
+		self.assertEqual(entry.get_path(), Path(':'))
+
+		TestPageEntry.runTest(self)
+
+
 class TestLinkEntry(TestPageEntry, TestFileEntry):
 
 	entryklass = LinkEntry
@@ -172,7 +198,7 @@ class TestLinkEntry(TestPageEntry, TestFileEntry):
 		TestFileEntry.runTest(self)
 
 
-class TestInputForm(TestCase):
+class TestInputForm(tests.TestCase):
 
 	def runTest(self):
 		'''Test InputForm widget'''
@@ -231,7 +257,7 @@ class TestInputForm(TestCase):
 
 				self.assertEqual(U[k], v)
 
-		notebook = get_test_notebook()
+		notebook = tests.new_notebook()
 		form = InputForm(inputs, values1, notebook=notebook)
 
 		for input in inputs:
@@ -256,12 +282,11 @@ class TestInputForm(TestCase):
 		self.assertEqual(i, 9)
 
 
-class TestFileDialog(TestCase):
-
-	slowTest = True
+@tests.slowTest
+class TestFileDialog(tests.TestCase):
 
 	def runTest(self):
-		tmp_dir = create_tmp_dir('widgets_TestFileDialog')
+		tmp_dir = self.create_tmp_dir()
 
 		file = File((tmp_dir, 'test.txt'))
 		file.write('test 123')
@@ -280,5 +305,3 @@ class TestFileDialog(TestCase):
 		# TODO select folder
 
 		# TODO add filters
-
-
