@@ -640,7 +640,7 @@ class ConfigDict(ListDict):
 				parameter, value = line.split('=', 1)
 				parameter = str(parameter.rstrip()) # no unicode
 				try:
-					value = self._decode_value(value.lstrip())
+					value = self._decode_value(parameter, value.lstrip())
 					section[parameter] = value
 				except:
 					logger.warn('Failed to parse value for: %s', parameter)
@@ -648,7 +648,8 @@ class ConfigDict(ListDict):
 				logger.warn('Could not parse line: %s', line)
 
 	# Separated out as this will be slightly different for .desktop files
-	def _decode_value(self, value):
+	# we ignore the key - but DesktopEntryDict uses them
+	def _decode_value(self, key, value):
 		if len(value) == 0:
 			return ''
 		if value == 'True': return True
