@@ -1,13 +1,14 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2008 Jaap Karssenberg <pardus@cpan.org>
+# Copyright 2008 Jaap Karssenberg <jaap.karssenberg@gmail.com>
 
 import gtk
 
-from zim.fs import *
-from zim.exporter import Exporter
 import zim.formats
 import zim.templates
+
+from zim.fs import File, Dir
+from zim.exporter import Exporter
 from zim.stores import encode_filename
 from zim.gui.widgets import Assistant, AssistantPage, \
 	ProgressBarDialog, ErrorDialog, QuestionDialog
@@ -51,7 +52,7 @@ class ExportDialog(Assistant):
 					_('Folder exists: %s') % dir.path, # T: message heading
 					_('Folder already exists and has content, '
 					  'exporting to this folder may overwrite '
-					  'exisitng files. '
+					  'existing files. '
 					  'Do you want to continue?' ) # T: detailed message, answers are Yes and No
 				) ).run()
 				if not ok:
@@ -122,7 +123,7 @@ class InputPage(AssistantPage):
 			'page': 'selection:page',
 			#~ 'recursive': 'selection:page',
 		} )
-		self.form.widgets['page'].force_existing = True
+		self.form.widgets['page'].existing_only = True
 
 	def init_uistate(self):
 		#~ self.uistate.setdefault('selection', 'all', ('all', 'page'))
@@ -193,7 +194,7 @@ class FormatPage(AssistantPage):
 							o.get_active_text() == self.CHOICE_OTHER) )
 
 		# Check if we have a document root - if not disable all options
-		docroot = assistant.ui.notebook.get_document_root()
+		docroot = assistant.ui.notebook.document_root
 		if not docroot:
 			for widget in self.form.widgets:
 				if widget.startswith('document_root:'):
@@ -274,7 +275,7 @@ class OutputPage(AssistantPage):
 			ext = zim.formats.get_format(self.uistate['format']).info['extension']
 			file = File('~/' + encode_filename(basename  + '.' + ext))
 			self.uistate['output_file'] = file
-			# TODO rememeber last file output folder
+			# TODO remember last file output folder
 
 		self.form['file'] = self.uistate['output_file']
 		self.form['folder'] = self.uistate['output_folder']
