@@ -11,13 +11,13 @@ class PropertiesDialog(Dialog):
 		Dialog.__init__(self, ui, _('Properties')) # T: Dialog title
 		label = gtk.Label()
 		label.set_markup('<b>'+_('Notebook Properties')+'</b>')
-			# T: Section in notbook dialog
+			# T: Section in notebook dialog
 		label.set_alignment(0.0, 0.5)
 		self.vbox.pack_start(label, False)
 		fields = []
 		config = self.ui.notebook.config['Notebook']
-		for name, type, label in self.ui.notebook.properties:
-			fields.append((name, type, label))
+		for item in self.ui.notebook.properties:
+			fields.append(item)
 		self.add_form(fields, values=config)
 		self.form.widgets['icon'].set_use_relative_paths(self.ui.notebook)
 		if self.ui.readonly:
