@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2008 Jaap Karssenberg <pardus@cpan.org>
+# Copyright 2008 Jaap Karssenberg <jaap.karssenberg@gmail.com>
 
 '''This module stands apart from the rest of the gui modules as it is not
 part from the main Gtk interface. It defines a Gtk interface that can be
@@ -11,7 +11,7 @@ import gtk
 import webbrowser # FIXME replace with XDG aware method
 
 from zim.config import data_file
-from zim.gui.widgets import IconButton, gtk_window_set_default_icon
+from zim.gui.widgets import IconButton, gtk_window_set_default_icon, ErrorDialog
 from zim.gui.notebookdialog import NotebookComboBox, NotebookDialog
 
 stock_started = ('gtk-yes', gtk.ICON_SIZE_DIALOG)
@@ -31,11 +31,18 @@ class ServerWindow(gtk.Window):
 		self.server.connect_after('stopped', self.do_server_stopped)
 
 		def _start(*a):
-			self.server.set_notebook(
-				self.notebookcombobox.get_notebook() )
-			self.server.start()
+			try:
+				self.server.set_notebook(
+					self.notebookcombobox.get_notebook() )
+				self.server.start()
+			except Exception, error:
+				ErrorDialog(self, error).run()
 
-		def _stop(*a): self.server.stop()
+		def _stop(*a):
+			try:
+				self.server.stop()
+			except Exception, error:
+				ErrorDialog(self, error).run()
 
 		# Build the interface
 		vbox = gtk.VBox()
@@ -92,7 +99,7 @@ class ServerWindow(gtk.Window):
 		table.attach(open_button, 2,3, 0,1)
 
 		table.attach(gtk.Label(_('Port')+': '), 0,1, 1,2)
-			# T: Field in web server gui for HTTLP port (e.g. port 80)
+			# T: Field in web server gui for HTTP port (e.g. port 80)
 		self.portentry = gtk.SpinButton()
 		self.portentry.set_numeric(True)
 		self.portentry.set_range(80, 10000)
