@@ -1,14 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2008 Jaap Karssenberg <pardus@cpan.org>
+# Copyright 2008 Jaap Karssenberg <jaap.karssenberg@gmail.com>
 
-'''This module contains the history class.
+'''This module implements the history for navigating pages in the
+notebook.
 
-The history can be represented as a list of pages with extra columns for the
-cursor and scroll positions. One additional property is used to give the current
-page in that list. All entries before the current position can be accessed by
-navigating backward, all entries ahead of the current position can be accessed
-by navigating forward. The same page can occur multiple times in the list.
+The main class is L{History}. Also there is a specialized class
+L{HistoryPath} which extends L{Path} with history information.
 '''
 
 import gobject
@@ -24,13 +22,13 @@ logger = logging.getLogger('zim.history')
 
 
 class HistoryPath(Path):
-	'''Path withsome additional info from the history.
+	'''Path with some additional info from the history.
 
-	Adds attributes 'cursor', 'scroll', 'is_first' and 'is_last'.
-	Both 'cursor' and 'scroll' give a position within the page and
-	should be integer, or None when undefined.
-	Both 'is_first' and 'is_last' are boolean and show whether this
-	record is the first or last record in the history.
+	@ivar cursor: cursor position as integer offset from start of the
+	text buffer
+	@ivar scroll: scroll position of the text view as integer
+	@ivar is_first: C{True} when this is the first path in the history
+	@ivar is_last: C{True} when this is the last path in the history
 	'''
 
 	__slots__ = ('cursor', 'scroll', 'deleted', 'is_first', 'is_last')
@@ -51,11 +49,16 @@ class HistoryPath(Path):
 
 
 class HistoryList(list):
-	# Wrapper for a list of HistoryPaths which takes care of (de-)serialization
-	# when saving in the config
+	'''A list of L{HistoryPath}s which takes care of serialization
+	when saving in a config file, and de-serialization on construction.
+	'''
 
 	def __init__(self, list):
-		# Convert list from config to use Path objects
+		'''Constructor
+		@param list: a list of 3-tuples giving path name, cursor
+		position and scroll position. Will be converted in a list with
+		L{HistoryPath}s
+		'''
 		try:
 			for name, cursor, scroll in list:
 				self.append(HistoryPath(name, cursor, scroll))
@@ -80,15 +83,26 @@ class HistoryList(list):
 		return ids.index(id(path))
 
 	def serialize_zim_config(self):
+		'''Serialize to string
+		@returns: the list content as a json formatted string
+		'''
 		data = [(path.name, path.cursor, path.scroll) for path in self]
 		return json.dumps(data, separators=(',',':'))
 
 
 class History(gobject.GObject):
-	'''History class.
+	'''History class, keeps track of a list of L{HistoryPath} objects.
+	Also has a 'current' page which should match the current page in the
+	interface. The current page normally is the latest page in the list,
+	but when the user navigates back in the history it can be another
+	position.
 
-	Signals:
-		* changed - emitted whenever something changes
+	@ivar current: list index for the current page
+	@ivar history: the L{HistoryList}
+	@ivar notebook: the L{Notebook}
+	@ivar uistate: the L{ConfigDict} used to store the history
+
+	@signal: C{changed ()}: emitted when the path list changed
 	'''
 	# TODO should inherit from the selection object ?
 
@@ -98,6 +112,11 @@ class History(gobject.GObject):
 	}
 
 	def __init__(self, notebook, uistate=None):
+		'''Constructor
+		@param notebook: a L{Notebook} object
+		@param uistate: L{ConfigDict} to store the history (history
+		will use the 'History' section in ConfigDict)
+		'''
 		gobject.GObject.__init__(self)
 		self.notebook = notebook
 		if uistate is None:
@@ -182,6 +201,11 @@ class History(gobject.GObject):
 			self.emit('changed')
 
 	def append(self, page):
+		'''Append a new page to the history. Will drop the forward
+		stack and make this page the latest page.
+		@param page: L{Path} for the current page
+		@emits: changed
+		'''
 		# drop forward stack
 		while len(self.history) - 1 > self.current:
 			self.history.pop()
@@ -203,40 +227,71 @@ class History(gobject.GObject):
 		self.emit('changed')
 
 	def get_current(self):
+		'''Get current path
+		@returns: a L{HistoryPath} object
+		'''
 		if self.history:
 			return self.history[self.current]
 		else:
 			return None
 
 	def set_current(self, path):
+		'''Set current path (changes the pointer, does not change
+		the list of pages)
+		@param path: a L{HistoryPath} object
+		@raises ValueError:  when the path is not in the history list
+		'''
 		assert isinstance(path, HistoryPath)
 		self.current = self.history.index(path)
 			# fails if path not in history
 
 	def get_previous(self):
+		'''Get the previous path
+		@returns: a L{HistoryPath} object or C{None} if current is
+		already the first path in the list
+		'''
 		if len(self.history) > 1 and self.current > 0:
 			return self.history[self.current - 1]
 		else:
 			return None
 
 	def get_next(self):
+		'''Get the next path
+		@returns: a L{HistoryPath} object or C{None} if current is
+		already the last path in the list
+		'''
 		if self.current < len(self.history) - 1:
 			return self.history[self.current + 1]
 		else:
 			return None
 
 	def get_child(self, path):
-		'''Returns a path for a direct child of path or None'''
+		'''Get the most recent path that is a direct child of the
+		given path. If there is a recent grand-child of the given path
+		in the history, that will be used as a bases to get a new
+		L{Path} object. Used by the keybinding for navigating to child
+		pages.
+		@param path: a L{Path} object
+		@returns: a L{HistoryPath} or L{Path} object or C{None}
+		'''
 		for i in range(len(self.history)-1, -1, -1):
 			if self.history[i].ischild(path):
 				relname = self.history[i].relname(path)
-				basename = relname.split(':')[0]
-				return path + basename
+				if ':' in relname:
+					basename = relname.split(':')[0]
+					return path + basename
+				else:
+					return self.history[i]
 		else:
 			return None
 
 	def get_grandchild(self, path):
-		'''Returns a path for the deepest child of path that could be found or None'''
+		'''Get the deepest nested gran-child of a given path. Used
+		for the 'namepsace' pathbar to keep showing child pages when
+		the user navigates up.
+		@param path: a L{Path} object
+		@returns: a L{HistoryPath} object or C{None}
+		'''
 		child = path
 		for i in range(len(self.history)-1, -1, -1):
 			if self.history[i].ischild(child):
@@ -245,13 +300,39 @@ class History(gobject.GObject):
 		if child == path: return None
 		else: return child
 
+	def get_path(self, path, need_cursor=False):
+		'''Get a L{HistoryPath} for a given path. Just looks for the
+		first occurence of the path in the history list and returns
+		the corresponding L{HistoryPath}. Used e.g. by the interface to
+		find out the latest cursor position for a page.
+
+		@param path: a L{Path} object
+		@param need_cursor: if C{True} only history records are
+		returned that have a value for the cursor that is not C{None}
+
+		@returns: a L{HistoryPath} object or None
+		'''
+		for record in self.get_history():
+			if record == path:
+				if need_cursor:
+					if not record.cursor is None:
+						return record
+					else:
+						continue
+				else:
+					return record
+
 	def get_history(self):
-		'''Generator function that yields history records, latest first'''
+		'''Generator function that yields history records, latest first
+		@returns: yields L{HistoryPath} objects
+		'''
 		for i in range(len(self.history)-1, -1, -1):
 			yield self.history[i]
 
 	def get_unique(self):
-		'''Generator function that yields unique records'''
+		'''Generator function that yields unique pages in the history
+		@returns: yields L{HistoryPath} objects
+		'''
 		seen = set()
 		for i in range(len(self.history)-1, -1, -1):
 			path = self.history[i]
