@@ -9,7 +9,7 @@ from datetime import date as dateclass
 
 from zim.plugins import PluginClass
 from zim.config import config_file, data_file
-from zim.notebook import get_notebook, Notebook, PageNameError
+from zim.notebook import resolve_notebook, get_notebook, Notebook, PageNameError
 from zim.daemon import DaemonProxy
 from zim.gui.widgets import Dialog, scrolled_text_view, IconButton, \
 	InputForm, gtk_window_set_default_icon
@@ -17,6 +17,11 @@ from zim.gui.notebookdialog import NotebookComboBox
 from zim.templates import GenericTemplate, StrftimeFunction
 
 
+import logging
+
+logger = logging.getLogger('zim.plugins.quicknote')
+
+
 usagehelp = '''\
 usage: zim --plugin quicknote [OPTIONS]
 
@@ -56,11 +61,15 @@ def main(daemonproxy, *args):
 			dict[arg] = True
 	#~ print 'OPTIONS:', options, template_options
 
-
 	if 'help' in options:
 		print usagehelp
 		return
 
+	if 'notebook' in options:
+		notebook, page = resolve_notebook(options['notebook'])
+	else:
+		notebook = None
+
 	if 'input' in options:
 		if options['input'] == 'stdin':
 			import sys
@@ -89,7 +98,7 @@ def main(daemonproxy, *args):
 	gtk_window_set_default_icon()
 
 	dialog = QuickNoteDialog(None,
-		options.get('notebook'),
+		notebook,
 		options.get('namespace'), options.get('basename'),
 		text, template_options )
 	dialog.run()
@@ -254,7 +263,8 @@ class BoundQuickNoteDialog(Dialog):
 			# Automatically generate a (valid) page name
 			self._updating_title = True
 			bounds = buffer.get_bounds()
-			title = buffer.get_text(*bounds).strip()[:25]
+			title = buffer.get_text(*bounds).strip()[:50]
+				# Cut off at 50 characters to prevent using a whole paragraph
 			title = title.replace(':', '')
 			if '\n' in title:
 				title, _ = title.split('\n', 1)
@@ -307,6 +317,9 @@ class QuickNoteDialog(BoundQuickNoteDialog):
 		self._updating_title = False
 		self._title_set_manually = not basename is None
 
+		if notebook and not isinstance(notebook, basestring):
+			notebook = notebook.uri
+
 		self.uistate.setdefault('lastnotebook', None, basestring)
 		if self.uistate['lastnotebook']:
 			notebook = notebook or self.uistate['lastnotebook']
@@ -327,9 +340,8 @@ class QuickNoteDialog(BoundQuickNoteDialog):
 
 		self._init_inputs(namespace, basename, text, template_options)
 
-		self.notebook = notebook
-		if notebook:
-			self.form.widgets['namespace'].notebook = get_notebook(notebook)
+		self.uistate['lastnotebook'] = notebook
+		self._set_autocomplete(notebook)
 
 	def save_uistate(self):
 		notebook = self.notebookcombobox.get_notebook()
@@ -344,7 +356,7 @@ class QuickNoteDialog(BoundQuickNoteDialog):
 
 	def on_notebook_changed(self, o):
 		notebook = self.notebookcombobox.get_notebook()
-		if not notebook or notebook == self.notebook:
+		if not notebook or notebook == self.uistate['lastnotebook']:
 			return
 
 		self.uistate['lastnotebook'] = notebook
@@ -353,7 +365,19 @@ class QuickNoteDialog(BoundQuickNoteDialog):
 		if namespace:
 			self.form['namespace'] = namespace
 
-		self.form.widgets['namespace'].notebook = get_notebook(notebook)
+		self._set_autocomplete(notebook)
+
+	def _set_autocomplete(self, notebook):
+		if notebook:
+			obj = get_notebook(notebook)
+			self.form.widgets['namespace'].notebook = obj
+			self.form.widgets['page'].notebook = obj
+			# Could still be None, e.g. if the notebook folder is not mounted
+			logger.debug('Notebook for autocomplete: %s (%s)', obj, notebook)
+		else:
+			self.form.widgets['namespace'].notebook = None
+			self.form.widgets['page'].notebook = None
+			logger.debug('Notebook for autocomplete unset')
 
 	def do_response_ok(self):
 		def get_ui():
