@@ -242,7 +242,8 @@ class StatusIconTrayIcon(TrayIconBase, gtk.StatusIcon):
 
 	def __init__(self):
 		gtk.StatusIcon.__init__(self)
-		self.set_from_icon_name('zim')
+		icon = data_file('zim.png').path
+		self.set_from_file(icon)
 		self.set_tooltip(_('Zim Desktop Wiki')) # T: tooltip for tray icon
 		self.connect('popup-menu', self.__class__.do_popup_menu)
 
@@ -357,6 +358,9 @@ class AppIndicatorTrayIcon(DaemonTrayIconMixin, TrayIconBase):
 	def __init__(self):
 		DaemonTrayIconMixin.__init__(self)
 
+		# Note that even though we specify the icon "zim", the
+		# ubuntu appindicator framework will first check for an icon
+		# "zim-panel". This way it finds the mono color icons.
 		self.appindicator = appindicator.Indicator(
 			'zim-desktop-wiki', 'zim', appindicator.CATEGORY_APPLICATION_STATUS)
 		self.appindicator.set_status(appindicator.STATUS_ACTIVE)
